==> open-xchange-guard_2.8.0.orig.tar.bz2: open-xchange-guard-2.8.0/com.openexchange.guard.management/src/com/openexchange/guard/management/maintenance/GuardMaintenanceMBean.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.management.maintenance;

import java.rmi.RemoteException;
import javax.management.MBeanException;
import com.openexchange.guard.management.maintenance.internal.TestUserResult;

/**
 * {@link GuardMaintenanceMBean}
 *
 * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
 */
public interface GuardMaintenanceMBean {

    public static final String DOMAIN = "com.openexchange.guard";

    public static final String KEY = "name";

    public static final String VALUE = "GuardManagement";

    public static final String DESCRIPTION = "Management Bean for the OX Guard";

    /**
     * Reset the password for the specified user
     *
     * @param email The user's email address for which to reset the password
     * @throws RemoteException
     */
    void reset(String email) throws MBeanException;

    /**
     * Remove the PIN for the specified user
     *
     * @param email The user's email address for which to remove the PIN
     * @throws RemoteException
     */
    void removePIN(String email) throws MBeanException;

    /**
     * Upgrade the account of the specified user
     *
     * @param email The user's email address for which to perform the upgrade
     * @throws RemoteException
     */
    void upgrade(String email) throws MBeanException;

    /**
     * Perform a simple test for the provided e-mail address
     *
     * @param email The e-mail address of the user
     * @throws RemoteException
     */
    String test(String email) throws MBeanException;

    /**
     * Perform a simple test for the provided e-mail address
     *
     * @param email The e-mail address of the user
     * @throws RemoteException
     */
    TestUserResult testUser(String email) throws MBeanException;

    /**
     * Deletes a user from Guard
     * @param email
     * @throws MBeanException
     */
    void deleteUser(String email) throws MBeanException;

    /**
     * Resets a Guest account with new Keys
     * @param email
     * @param force
     * @throws MBeanException
     */
    void resetGuest(String email, boolean force) throws MBeanException;

    /**
     * Changes email, userid, or context of a user Identified by email
     * @param email
     * @param newEmail
     * @throws MBeanException
     */
    void changeUser(String email, String newEmail) throws MBeanException;

}

==> open-xchange-guard_2.10.4.orig.tar.bz2: open-xchange-guard-2.10.4/com.openexchange.guard.management/src/com/openexchange/guard/management/maintenance/GuardMaintenanceMBean.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.management.maintenance;

import java.rmi.RemoteException;
import javax.management.MBeanException;
import com.openexchange.guard.management.maintenance.internal.TestUserResult;

/**
 * {@link GuardMaintenanceMBean}
 *
 * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
 */
public interface GuardMaintenanceMBean {

    public static final String DOMAIN = "com.openexchange.guard";

    public static final String KEY = "name";

    public static final String VALUE = "GuardManagement";

    public static final String DESCRIPTION = "Management Bean for the OX Guard";

    /**
     * Reset the password for the specified user
     *
     * @param email The user's email address for which to reset the password
     * @throws RemoteException
     */
    void reset(String email) throws MBeanException;

    /**
     * Remove the PIN for the specified user
     *
     * @param email The user's email address for which to remove the PIN
     * @throws RemoteException
     */
    void removePIN(String email) throws MBeanException;

    /**
     * Upgrade the account of the specified user
     *
     * @param email The user's email address for which to perform the upgrade
     * @param userid The users user_id
     * @param cid The users context
     * @throws RemoteException
     */
    void upgrade(String email, String userid, String cid) throws MBeanException;

    /**
     * Perform a simple test for the provided e-mail address
     *
     * @param email The e-mail address of the user
     * @throws RemoteException
     */
    String test(String email) throws MBeanException;

    /**
     * Perform a simple test for the provided e-mail address
     *
     * @param email The e-mail address of the user
     * @throws RemoteException
     */
    TestUserResult testUser(String email) throws MBeanException;

    /**
     * Deletes a user from Guard
     * @param email
     * @throws MBeanException
     */
    void deleteUser(String email) throws MBeanException;

    /**
     * Resets a Guest account with new Keys
     * @param email
     * @param force
     * @throws MBeanException
     */
    void resetGuest(String email, boolean force) throws MBeanException;

    /**
     * Imports a PGP Public Key into System keys for HKP server
     * @param file
     * @throws MBeanException
     */
    void importPublic(String file) throws MBeanException;

    /**
     * Attempts validation and repair of guard database
     * @throws MBeanException
     */
    StringBuilder repair (boolean dryRun) throws MBeanException;

    /**
     * Changes email, userid, or context of a user Identified by email
     * @param email
     * @param newEmail
     * @throws MBeanException
     */
    void changeUser(String email, String newEmail) throws MBeanException;

}
